==> djaodjin-multitier-0.1.5.tar.gz: djaodjin-multitier-0.1.5/multitier/utils.py <==
# Copyright (c) 2017, Djaodjin Inc.
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
#
# 1. Redistributions of source code must retain the above copyright notice,
#    this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright notice,
#    this list of conditions and the following disclaimer in the documentation
#    and/or other materials provided with the distribution.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
# AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
# THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
# PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR
# CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
# EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
# PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
# OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
# WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
# OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
# ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

from django.apps import apps as django_apps
from django.conf import settings as django_settings
from django.core.exceptions import ImproperlyConfigured

def get_site_model():
    """
    Returns the ``Site`` model that is active in this Django project.
    """
    if hasattr(django_settings, 'MULTITIER_SITE_MODEL'):
        try:
            return django_apps.get_model(django_settings.MULTITIER_SITE_MODEL)
        except ValueError:
            raise ImproperlyConfigured("MULTITIER_SITE_MODEL must be "\
                "of the form 'app_label.model_name'")
        except LookupError:
            raise ImproperlyConfigured("MULTITIER_SITE_MODEL refers to model"\
                " '%s' that has not been installed"
                % django_settings.MULTITIER_SITE_MODEL)

    return django_apps.get_model('multitier.Site')

==> djaodjin-multitier-0.1.15.tar.gz: djaodjin-multitier-0.1.15/multitier/utils.py <==
# Copyright (c) 2019, Djaodjin Inc.
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
#
# 1. Redistributions of source code must retain the above copyright notice,
#    this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright notice,
#    this list of conditions and the following disclaimer in the documentation
#    and/or other materials provided with the distribution.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
# AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
# THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
# PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR
# CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
# EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
# PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
# OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
# WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
# OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
# ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

from django.apps import apps as django_apps
from django.core.exceptions import ImproperlyConfigured

from . import settings


def get_site_model():
    """
    Returns the ``Site`` model that is active in this Django project.
    """
    if hasattr(settings, 'MULTITIER_SITE_MODEL'):
        try:
            return django_apps.get_model(settings.MULTITIER_SITE_MODEL)
        except ValueError:
            raise ImproperlyConfigured("MULTITIER_SITE_MODEL must be "\
                "of the form 'app_label.model_name'")
        except LookupError:
            raise ImproperlyConfigured("MULTITIER_SITE_MODEL refers to model"\
                " '%s' that has not been installed"
                % settings.MULTITIER_SITE_MODEL)

    return django_apps.get_model('multitier.Site')
